@@ -202,6 +202,7 @@ class TokenType(AutoName):
     SIMPLEAGGREGATEFUNCTION = auto()
     TDIGEST = auto()
     UNKNOWN = auto()
+    VECTOR = auto()
 
     # keywords
     ALIAS = auto()
@@ -526,6 +527,7 @@ class _Tokenizer(type):
                     _TOKEN_TYPE_TO_INDEX[v] for v in klass.COMMAND_PREFIX_TOKENS
                 },
                 heredoc_tag_is_identifier=klass.HEREDOC_TAG_IS_IDENTIFIER,
+                string_escapes_allowed_in_raw_strings=klass.STRING_ESCAPES_ALLOWED_IN_RAW_STRINGS,
             )
             token_types = RsTokenTypeSettings(
                 bit_string=_TOKEN_TYPE_TO_INDEX[TokenType.BIT_STRING],
@@ -602,6 +604,9 @@ class Tokenizer(metaclass=_Tokenizer):
     # Token that we'll generate as a fallback if the heredoc prefix doesn't correspond to a heredoc
     HEREDOC_STRING_ALTERNATIVE = TokenType.VAR
 
+    # Whether string escape characters function as such when placed within raw strings
+    STRING_ESCAPES_ALLOWED_IN_RAW_STRINGS = True
+
     # Autofilled
     _COMMENTS: t.Dict[str, str] = {}
     _FORMAT_STRINGS: t.Dict[str, t.Tuple[str, TokenType]] = {}
@@ -877,6 +882,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "DATERANGE": TokenType.DATERANGE,
         "DATEMULTIRANGE": TokenType.DATEMULTIRANGE,
         "UNIQUE": TokenType.UNIQUE,
+        "VECTOR": TokenType.VECTOR,
         "STRUCT": TokenType.STRUCT,
         "SEQUENCE": TokenType.SEQUENCE,
         "VARIANT": TokenType.VARIANT,
@@ -1162,10 +1168,22 @@ class Tokenizer(metaclass=_Tokenizer):
             # Skip the comment's start delimiter
             self._advance(comment_start_size)
 
+            comment_count = 1
             comment_end_size = len(comment_end)
-            while not self._end and self._chars(comment_end_size) != comment_end:
+
+            while not self._end:
+                if self._chars(comment_end_size) == comment_end:
+                    comment_count -= 1
+                    if not comment_count:
+                        break
+
                 self._advance(alnum=True)
 
+                # Nested comments are allowed by some dialects, e.g. databricks, duckdb, postgres
+                if not self._end and self._chars(comment_end_size) == comment_start:
+                    self._advance(comment_start_size)
+                    comment_count += 1
+
             self._comments.append(self._text[comment_start_size : -comment_end_size + 1])
             self._advance(comment_end_size - 1)
         else:
@@ -1280,7 +1298,7 @@ class Tokenizer(metaclass=_Tokenizer):
                 else:
                     tag = self._extract_string(
                         end,
-                        unescape_sequences=False,
+                        raw_string=True,
                         raise_unmatched=not self.HEREDOC_TAG_IS_IDENTIFIER,
                     )
 
@@ -1297,7 +1315,7 @@ class Tokenizer(metaclass=_Tokenizer):
             return False
 
         self._advance(len(start))
-        text = self._extract_string(end, unescape_sequences=token_type != TokenType.RAW_STRING)
+        text = self._extract_string(end, raw_string=token_type == TokenType.RAW_STRING)
 
         if base:
             try:
@@ -1333,7 +1351,7 @@ class Tokenizer(metaclass=_Tokenizer):
         self,
         delimiter: str,
         escapes: t.Optional[t.Set[str]] = None,
-        unescape_sequences: bool = True,
+        raw_string: bool = False,
         raise_unmatched: bool = True,
     ) -> str:
         text = ""
@@ -1342,7 +1360,7 @@ class Tokenizer(metaclass=_Tokenizer):
 
         while True:
             if (
-                unescape_sequences
+                not raw_string
                 and self.dialect.UNESCAPED_SEQUENCES
                 and self._peek
                 and self._char in self.STRING_ESCAPES
@@ -1353,7 +1371,8 @@ class Tokenizer(metaclass=_Tokenizer):
                     text += unescaped_sequence
                     continue
             if (
-                self._char in escapes
+                (self.STRING_ESCAPES_ALLOWED_IN_RAW_STRINGS or not raw_string)
+                and self._char in escapes
                 and (self._peek == delimiter or self._peek in escapes)
                 and (self._char not in self._QUOTES or self._char == self._peek)
             ):
