@@ -204,6 +204,7 @@ USE ROLE x
 USE WAREHOUSE x
 USE DATABASE x
 USE SCHEMA x.y
+USE CATALOG abc
 NOT 1
 NOT NOT 1
 SELECT * FROM test
@@ -870,3 +871,4 @@ SELECT unnest
 SELECT * FROM a STRAIGHT_JOIN b
 SELECT COUNT(DISTINCT "foo bar") FROM (SELECT 1 AS "foo bar") AS t
 SELECT vector
+WITH all AS (SELECT 1 AS count) SELECT all.count FROM all
\ No newline at end of file
